@@ -1366,21 +1366,20 @@ int main (int argc, char **argv)
   loader_window = hildon_stackable_window_new();
   image_window  = hildon_stackable_window_new();
 
+  gtk_container_add (GTK_CONTAINER(player_window), player_page);
+  gtk_container_add (GTK_CONTAINER(loader_window), loader_page);
+  gtk_container_add (GTK_CONTAINER(image_window), image_page);
+
   hildon_program_add_window (program, HILDON_WINDOW (player_window));
   hildon_program_add_window (program, HILDON_WINDOW (loader_window));
   hildon_program_add_window (program, HILDON_WINDOW (image_window));
 
-  gtk_widget_show(player_window);
+  printf("player window pointer %p!\n", player_window);
 
-  printf("window pointer %p!\n", player_window);
+  g_signal_connect (G_OBJECT(player_button), "clicked", G_CALLBACK (show_window), player_window);
+  g_signal_connect (G_OBJECT(loader_button), "clicked", G_CALLBACK (show_window), loader_window);
+  g_signal_connect (G_OBJECT(image_button),  "clicked", G_CALLBACK (show_window), image_window);
 
-  g_signal_connect (G_OBJECT(player_button), "clicked", G_CALLBACK (show_window), (gpointer)player_window);
-  g_signal_connect (G_OBJECT(loader_button), "clicked", G_CALLBACK (show_window), (gpointer)loader_window);
-  g_signal_connect (G_OBJECT(image_button),  "clicked", G_CALLBACK (show_window), (gpointer)image_window);
-
-  gtk_container_add (GTK_CONTAINER(player_window), player_page);
-  gtk_container_add (GTK_CONTAINER(loader_window), loader_page);
-  gtk_container_add (GTK_CONTAINER(image_window), image_page);
 
 #endif
 
